reduce_128_to_crc

Function reduce_128_to_crc 

unsafe fn reduce_128_to_crc(x: __m128i, data: &[u8]) -> u32
Folds any remaining 16-byte chunks into x, then folds a final partial (< 16 byte) block with a byte-shift, reduces from 128 to 32 bits with a Barrett reduction, and returns the CRC. Shared by all of the fold implementations.